@@ -3,14 +3,14 @@
 #'Use boostrapping to generate confidence intervals, or confidence regions in
 #'the case of the zero-inflated model.
 #'
-#'@param x a object of class \code{psFit}---see \code{\link{readData}} for more
-#'  details.
+#'@param x a object either of class \code{psData}---see \code{\link{readData}} for more
+#'  details---or of class \code{psFit}.
 #'@param level the confidence level required---restricted to [0.75, 1). This may
 #'  be a vector, in which case multiple intervals, or confidence regions will be
 #'  returned.
 #'@param B the number of bootstrap samples to take.
 #'@param model which model to fit to the data, either \code{"zeta"} or
-#'  \code{"zi.zeta"}. Maybe abbreviated to \code{"z"} and \code{"zi"}. Default
+#'  \code{"ziz"}. Maybe abbreviated to \code{"z"} and \code{"zi"}. Default
 #'  is \code{"zeta"}.
 #'@param returnBootValues if \code{TRUE} then the \code{vector} (or
 #'  \code{data.frame}) of bootstrapped values is returned. This can be useful
@@ -18,9 +18,9 @@
 #'@param silent if \code{TRUE}, then no output will be displayed whilst the
 #'  bootstrapping is being undertaken. \code{plot} if \code{TRUE} then the
 #'  contours for the confidence region will be plotted. This only works if
-#'  \code{model = "zi.zeta"}. It is ignored otherwise. \code{parallel} if
+#'  \code{model = "ziz"}. It is ignored otherwise. \code{parallel} if
 #'  \code{TRUE} then the bootstrapping is performed in parallel.
-#'@param plot if \code{TRUE} and \code{model == "zi.zeta"}, then a plot of the
+#'@param plot if \code{TRUE} and \code{model == "ziz"}, then a plot of the
 #'  bootstrapped values will be produced and confidence contour lines will be
 #'  drawn for each value in level.
 #'@param parallel if \code{TRUE}, then the package will attempt to use multiple
@@ -47,7 +47,8 @@
 #'  with elements/columns named \code{"lower"} and \code{"upper"} representing
 #'  the lower and upper bounds of the confidence interval(s). Multiple bounds
 #'  are returned in a \code{data.frame} when \code{level} has more than one
-#'  value. If \code{model == "zi.zeta"}, then a list with length equal to the
+#'  value. If \code{model == "ziz
+#'  "}, then a list with length equal to the
 #'  length of \code{level} is returned. The name of each element in the list is
 #'  the level with % attached. For example if \code{level == 0.95}, then the
 #'  list has a single element named \code{"95\%"}. It is possible for there to
@@ -68,7 +69,7 @@
 #' \dontrun{
 #' data(Psurveys)
 #' roux = Psurveys$roux
-#' confRegion = bootCI(roux, model = "zi.zeta", parallel = FALSE, plot = TRUE)
+#' confRegion = bootCI(roux, model = "ziz", parallel = FALSE, plot = TRUE)
 #'
 #' ## This will not work unless you have the sp package installed
 #' ## Count how many of the points lie within the 95% confidence region
@@ -96,7 +97,7 @@ bootCI = function(x, ...){
 bootCI.default = function(x,
                           level = 0.95,
                           B = 2000,
-                          model = c("zeta", "zi.zeta"),
+                          model = c("zeta", "ziz"),
                           returnBootValues = FALSE,
                           silent = FALSE,
                           plot = FALSE,
@@ -216,12 +217,11 @@ bootCI.psData = function(x, ...){
 
 #' @describeIn bootCI Bootstrap confidence intervals or regions
 #' @export
-bootCI.psFit = function(x, model = ifelse(!x$zeroInflated, "zeta", "zi.zeta"),
-                        ...){
-  return(bootCI.default(x = x$psData, model = model, ...))
+bootCI.psFit = function(x, ...){
+  return(bootCI.default(x = x$psData, model = x$model, ...))
 }
 
-bootFit = function(x, B = 2000, model = c("zeta", "zi.zeta"),
+bootFit = function(x, B = 2000, model = c("zeta", "ziz"),
                    silent = FALSE,
                    parallel = TRUE,
                    progressBar = FALSE,
