@@ -1,93 +1,14 @@
-# fitZIDist.old = function(x, nterms = 10,
-#                    start = c(0.5, 1),
-#                    ...){
-#   nvals = 1:nterms
-#   if(!is(x, "psData")){
-#     stop("x must be an object of class psData")
-#   }
-#
-#   if(start[1] <= 0 || start[1] >= 1){
-#     stop("The starting value for pi must be in (0, 1)")
-#   }
-#
-#   if(start[2] <= 0){
-#     stop("The Zeta function is undefined for shape = 0. Choose a start value > 0.")
-#   }
-#
-#   obsData = if(x$type == 'P'){ ## the main difference is that the values need 1 added
-#     x$data$n + 1
-#   }else{
-#     x$data$n
-#   }
-#
-#   y = rep(obsData, x$data$rn)
-#
-#   d.one.inflated.zeta = function(x, shape, p, log = FALSE){
-#     rval = (1 - p) * VGAM::dzeta(x, shape = shape)
-#     rval[x == 1] = rval[x == 1] + p
-#
-#     if(log){
-#       return(log(rval))
-#     }
-#     return(rval)
-#   }
-#
-#   logLik = function(params){
-#     p = params[1]
-#     shape = params[2]
-#
-#     r = -sum(d.one.inflated.zeta(y, shape, p, log = TRUE))
-#     if(is.infinite(r) || is.nan(r)){
-#       stop(sprintf("Infinite log-likelihod: pi = %6.4E shape = %6.4f\n", p, shape))
-#     }
-#     return(r)
-#   }
-#
-#   # fit = nlminb(start = start,
-#   #              objective = logLik,
-#   #              lower = 1)
-#
-#   fit = optim(par = start,
-#               fn = logLik,
-#               method = "L-BFGS-B",
-#               lower = c(0.1, 0.5), # in theory should be 0, 0 but I think this makes things unstable
-#               upper  = c(1 - .Machine$double.eps, Inf),
-#               hessian = TRUE)
-#
-#   fitted = d.one.inflated.zeta(nvals, shape = fit$par[2], p = fit$par[1])
-#   names(fitted) = if(x$type == 'P'){
-#     paste0("P", nvals - 1)
-#   }else{
-#     paste0("S", nvals)
-#   }
-#
-#   result = list(
-#     psData = x,
-#     fit = fit,
-#     shape =  fit$par[2],
-#     pi = fit$par[1],
-#     var.cov = solve(fit$hessian),
-#     fitted = fitted,
-#     zeroInflated = TRUE
-#   )
-#
-#
-#   class(result) = "psFit"
-#
-#   return(result)
-# }
-
 #' Fit a Zero-Inflated Zeta Distribution to Forensic Data
 #'
 #' This function uses maximum likelihood estimation (MLE) to estimate mixing
-#' parameter and the shape parameter of a Zero-Infalted Zeta distribution from a
+#' parameter and the shape parameter of a zero-inflated zeta distribution from a
 #' set of observed counts for either the number of groups/sources of
 #' forensically interesting material (mostly glass or paint) recovered from
 #' clothing, or the number of fragments/particles in each group. This, in turn,
 #' allows the estimation of the P and S probabilities, as described by Evett and
 #' Buckleton (1990), which used in computing the likelihood ratio (LR) for
 #' activity level propositions. The data itself arises from clothing surveys.
-#' The Zero-Inflated Zeta distribution has probability mass function
+#' The zero-inflated zeta distribution has probability mass function
 #' \deqn{p(k) = \begin{cases}
 #' \pi + \frac{(1-\pi)}{\zeta(s)}&,k=0, \\
 #' \frac{(1-\pi)k^{-s}}{\zeta(s)}&,k=1,2,\ldots
@@ -99,7 +20,7 @@
 #'
 #' @details The function returns an object of class \code{psFit} which is a
 #'   \code{list} contains seven elements:
-#' \itemize{
+#' \describe{
 #' \item{\code{psData}}{ -- an object of class \code{psData}--see \code{\link{readData}},}
 #' \item{\code{fit}}{ -- the fitted object from \code{\link[stats]{optim}},}
 #' \item{\code{pi}}{ - the maximum likelihood estimate of the mixing parameter,}
@@ -107,7 +28,7 @@
 #' \item{\code{var.cov}}{ -- the estimated variance-covariance matrix for the parameters,}
 #' \item{\code{fitted}}{ -- a named \code{vector} containing the first \code{nterms of
 #' the fitted distribution.}}
-#' \item{\code{zeroInflated}}{ -- set to \code{TRUE} for this model.}
+#' \item{\code{model}}{ -- set to \code{"ziz"} for this model.}
 #' }
 #'
 #' The output can be used in a variety of ways. If the interest is just in the
@@ -119,7 +40,7 @@
 #' function with \code{\link{probfun}}. **NOTE** The value of the shape
 #' parameter that is printed (if you print the fitted object) is different
 #' from that value that is stored in \code{shape}. The stored value is for the
-#' \pkg{VGAM} parameterisation of the Zeta distribution which uses
+#' \pkg{VGAM} parameterisation of the zeta distribution which uses
 #' \eqn{s^\prime = s - 1}{s' = s - 1}. Therefore the printed value is \eqn{s =
 #' s^\prime + 1}{s = s' + 1}. If you intend to use the fitted value with
 #' \code{\link[VGAM]{dzeta}}, then you should use the stored value
@@ -236,7 +157,7 @@ fitZIDist = function(x, nterms = 10,
     shape =  fit$par[2],
     var.cov = solve(fit$hessian),
     fitted = fitted,
-    zeroInflated = TRUE
+    model = "ziz"
   )
 
 
@@ -344,7 +265,7 @@ fitZIDistPL = function(x, nterms = 10,
     shape =  fit$par[2],
     var.cov = solve(fit$hessian),
     fitted = fitted,
-    zeroInflated = TRUE
+    model = "ziz"
   )
 
 
